==> haskell-http-api-data-0.4-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-api-data.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-api-data
version: 0.4
id: http-api-data-0.4-GYM1FHXzL1H4Yzt7cDRNIr
key: http-api-data-0.4-GYM1FHXzL1H4Yzt7cDRNIr
license: BSD-3-Clause
maintainer: Nickolay Kudasov <nickolay.kudasov@gmail.com>
author: Nickolay Kudasov <nickolay.kudasov@gmail.com>
stability: unstable
homepage: http://github.com/fizruk/http-api-data
synopsis: Converting to/from HTTP API data like URL pieces, headers and query parameters.
description:
    This package defines typeclasses used for converting Haskell data types to and from HTTP API data.
    .
    Please see README.md
category: Web
abi: a6bba1dff74320719e2e1431250d591b
exposed: True
exposed-modules:
    Web.FormUrlEncoded Web.HttpApiData Web.Internal.FormUrlEncoded
    Web.Internal.HttpApiData
import-dirs: /usr/lib/ghc-8.6.4/site-local/http-api-data-0.4
library-dirs: /usr/lib/ghc-8.6.4/site-local/http-api-data-0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/http-api-data-0.4
hs-libraries: HShttp-api-data-0.4-GYM1FHXzL1H4Yzt7cDRNIr
depends:
    attoparsec-0.13.2.2-3nUJVHBWBICGFmP4JcM3ay
    attoparsec-iso8601-1.0.1.0-2FWFXqEahGo6SeYLW9154S base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr bytestring-0.10.8.2
    containers-0.6.0.1 cookie-0.4.4-BFYr3M2B0n8F3gqLxXgKNx
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    http-types-0.12.3-D3aEnVjdeLuS27pc1eWXD
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP text-1.2.3.1 time-1.8.0.2
    time-locale-compat-0.1.1.5-4Kz46WDKPmGDmYVdO1w5q7
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    uuid-types-1.0.3-1r1IBIU9fBZK1eE2MZEQJb
haddock-interfaces: /usr/share/doc/haskell-http-api-data/html/http-api-data.haddock
haddock-html: /usr/share/doc/haskell-http-api-data/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-api-data-0.4-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-api-data.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-api-data
version: 0.4
id: http-api-data-0.4-JjitiXHGjAXCjV9615MAUx
key: http-api-data-0.4-JjitiXHGjAXCjV9615MAUx
license: BSD-3-Clause
maintainer: Nickolay Kudasov <nickolay.kudasov@gmail.com>
author: Nickolay Kudasov <nickolay.kudasov@gmail.com>
stability: unstable
homepage: http://github.com/fizruk/http-api-data
synopsis: Converting to/from HTTP API data like URL pieces, headers and query parameters.
description:
    This package defines typeclasses used for converting Haskell data types to and from HTTP API data.
    .
    Please see README.md
category: Web
abi: 56252b32ef9fc1b359becaad672a7c63
exposed: True
exposed-modules:
    Web.FormUrlEncoded Web.HttpApiData Web.Internal.FormUrlEncoded
    Web.Internal.HttpApiData
import-dirs: /usr/lib/ghc-8.6.5/site-local/http-api-data-0.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/http-api-data-0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/http-api-data-0.4
hs-libraries: HShttp-api-data-0.4-JjitiXHGjAXCjV9615MAUx
depends:
    attoparsec-0.13.2.2-3nUJVHBWBICGFmP4JcM3ay
    attoparsec-iso8601-1.0.1.0-2FWFXqEahGo6SeYLW9154S base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr bytestring-0.10.8.2
    containers-0.6.0.1 cookie-0.4.4-BFYr3M2B0n8F3gqLxXgKNx
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    http-types-0.12.3-FkUAYjCWW0WBZI2lM6bGTd
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP text-1.2.3.1 time-1.8.0.2
    time-locale-compat-0.1.1.5-4Kz46WDKPmGDmYVdO1w5q7
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    uuid-types-1.0.3-1r1IBIU9fBZK1eE2MZEQJb
haddock-interfaces: /usr/share/doc/haskell-http-api-data/html/http-api-data.haddock
haddock-html: /usr/share/doc/haskell-http-api-data/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
